from setuptools import setup

setup(
   name='apiterralab',
   version='0.0.1',
   description='breve descrição',
   author='TerraLab',
   author_email='terralab@gmail.com',
   packages=['apiterralab'],  #same as name
   install_requires=[], #external packages as dependencies
)